@@ -1,4 +1,5 @@
 # 开放平台接口基类
+from loguru import logger
 import requests
 
 
@@ -45,12 +46,23 @@ class base:
                 response = requests.post(
                     url, params=params, json=json, headers=headers)
             else:
-                raise ValueError("网络请求数据格式错误。")
+                logger.warning({
+                    "msg": "网络请求数据格式错误。",
+                    "method": "POST",
+                    "data": "没有任何数据请求，为什么不用GET？",
+                })
+                response = requests.post(url, params=params, headers=headers)
 
         else:
             raise ValueError("请求方法错误。")
         if response.status_code == 200:
+            # logger.debug({
+            #     "url": url,
+            #     "headers": headers,
+            #     "response": response.text,
+            # })
             return self.response(response.json())
 
     def response(self, response_raw):
+
         return response_raw
