@@ -18,15 +18,26 @@ class appMod(base):
 
     def request(self, **kwarg):
         api_prefix = ""
-        return super().request(api_prefix=api_prefix, **kwarg)
+        headers = {
+            "Cookie": f"accessToken={self.token}"
+        }
+        return super().request(api_prefix=api_prefix,
+                               headers=headers,
+                               ** kwarg)
 
-    def list(self, mod_name=None):
+    def list(self, mod_code=None, mod_name=None, cate_name=None, mod_type_id=None):
         data = dict(
             page=1,
             rows=100
         )
+        if mod_code:
+            data["param.modCode"] = mod_code
         if mod_name:
             data["param.modName"] = mod_name
+        if cate_name:
+            data["param.cateName"] = cate_name
+        if mod_type_id:
+            data["param.modType"] = mod_type_id
         return self.request(api_name="appModlist.jhtml",
                             data=data,
                             method="POST")
@@ -73,6 +84,27 @@ class appMod(base):
             data["response"] = response
             logger.debug(data)
 
+    def get_mod_type(self):
+        data = {}
+        response = self.request(api_name="appModgetAppModType.jhtml",
+                                data=data,
+                                method="POST"
+                                )
+        return response
+
+    def get_mod_type_id(self, type_name):
+        """
+        通过模块类型名称查找类型ID
+        """
+        for row in self.get_mod_type():
+            if type_name == row.get("mTypeName"):
+                type_id = row.get("mTypeId")
+                return type_id
+        logger.error({
+            "msg": "找不到模块类型",
+            "type_name": type_name,
+        })
+
 
 class appModCat(base):
     """
